==> zrythm-0.7.021.tar.xz: zrythm-0.7.021/inc/gui/widgets/chord_object.h <==
/*
 * Copyright (C) 2019 Alexandros Theodotou <alex at zrythm dot org>
 *
 * This file is part of Zrythm
 *
 * Zrythm is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Zrythm is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Zrythm.  If not, see <https://www.gnu.org/licenses/>.
 */

/**
 * \file
 *
 * Widget for ChordObject.
 */

#ifndef __GUI_WIDGETS_CHORD_OBJECT_H__
#define __GUI_WIDGETS_CHORD_OBJECT_H__

#include "gui/widgets/arranger_object.h"

#include <gtk/gtk.h>

#define CHORD_OBJECT_WIDGET_TYPE \
  (chord_object_widget_get_type ())
G_DECLARE_FINAL_TYPE (
  ChordObjectWidget,
  chord_object_widget,
  Z, CHORD_OBJECT_WIDGET,
  GtkBox);

typedef struct ChordObjectObject ChordObjectObject;

/**
 * @addtogroup widgets
 *
 * @{
 */

#define CHORD_OBJECT_WIDGET_TRIANGLE_W 10

/**
 * Widget for chords inside the ChordObjectTrack.
 */
typedef struct _ChordObjectWidget
{
  GtkBox           parent_instance;
  GtkDrawingArea * drawing_area;
  ChordObject *    chord_object;

  /** For double click. */
  GtkGestureMultiPress * mp;

  /** Set to 1 to redraw. */
  int                redraw;

  cairo_t *          cached_cr;

  cairo_surface_t *  cached_surface;
} ChordObjectWidget;

/**
 * Creates a chord widget.
 */
ChordObjectWidget *
chord_object_widget_new (
  ChordObject * chord);

void
chord_object_widget_force_redraw (
  ChordObjectWidget * self);

/**
 * @}
 */

#endif

==> zrythm-0.7.186.tar.xz: zrythm-0.7.186/inc/gui/widgets/chord_object.h <==
/*
 * Copyright (C) 2019 Alexandros Theodotou <alex at zrythm dot org>
 *
 * This file is part of Zrythm
 *
 * Zrythm is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Zrythm is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Zrythm.  If not, see <https://www.gnu.org/licenses/>.
 */

/**
 * \file
 *
 * Widget for ChordObject.
 */

#ifndef __GUI_WIDGETS_CHORD_OBJECT_H__
#define __GUI_WIDGETS_CHORD_OBJECT_H__

#include "gui/widgets/arranger_object.h"

#include <gtk/gtk.h>

/**
 * @addtogroup widgets
 *
 * @{
 */

#define CHORD_OBJECT_WIDGET_TRIANGLE_W 10
#define CHORD_OBJECT_NAME_FONT "Sans SemiBold 8"
#define CHORD_OBJECT_NAME_PADDING 2

/**
 * Recreates the pango layouts for drawing.
 *
 * @param width Full width of the marker.
 */
void
chord_object_recreate_pango_layouts (
  ChordObject * self);

/**
 *
 * @param cr Cairo context of the arranger.
 * @param rect Rectangle in the arranger.
 */
void
chord_object_draw (
  ChordObject *  self,
  cairo_t *      cr,
  GdkRectangle * rect);

#if 0

/**
 * Widget for chords inside the ChordObjectTrack.
 */
typedef struct _ChordObjectWidget
{
  ArrangerObjectWidget parent_instance;
  ChordObject *    chord_object;

  /** For double click. */
  GtkGestureMultiPress * mp;
} ChordObjectWidget;

/**
 * Creates a chord widget.
 */
ChordObjectWidget *
chord_object_widget_new (
  ChordObject * chord);
#endif

/**
 * @}
 */

#endif
